==> cutetube_1.7.2.tar.gz: cutetube-1.7.2/cutetubeapp/src/base/youtubeuserplaylistlistmodel.h <==
#ifndef YOUTUBEUSERPLAYLISTLISTMODEL_H
#define YOUTUBEUSERPLAYLISTLISTMODEL_H

#include "playlistitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

class Session;
class ThumbnailCache;

class YouTubeUserPlaylistListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Session* session
               READ session
               WRITE setSession)
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)

public:
    enum Roles {
        IdRole = Qt::UserRole + 1,
        PlaylistIdRole,
        TitleRole,
        ArtistRole,
        DateRole,
        VideoCountRole,
        ThumbnailRole,
        ThumbnailUrlRole,
        DescriptionRole
    };

public:
    explicit YouTubeUserPlaylistListModel(Session *session = 0, QObject *parent = 0);
    ~YouTubeUserPlaylistListModel();
    inline Session* session() const { return m_session; }
    void setSession(Session *session);
    inline ThumbnailCache* thumbnailCache() const { return m_cache; }
    void setThumbnailCache(ThumbnailCache *cache);
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    QSharedPointer<PlaylistItem> get(int row) const;
    Q_INVOKABLE PlaylistItem* getFromQML(int row) const;

private slots:
    void onPlaylistAdded(int row);
    void onPlaylistRemoved(int row);
    void onPlaylistUpdated(int row);
    void onThumbnailReady();

signals:
    void countChanged(int count);

private:
    Session *m_session;
    ThumbnailCache *m_cache;
};

#endif // YOUTUBEUSERPLAYLISTLISTMODEL_H

==> cutetube_1.8.2.tar.gz: cutetube-1.8.2/cutetubeapp/src/base/youtubeuserplaylistlistmodel.h <==
#ifndef YOUTUBEUSERPLAYLISTLISTMODEL_H
#define YOUTUBEUSERPLAYLISTLISTMODEL_H

#include "playlistitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

#ifndef QML_USER_INTERFACE
class ThumbnailCache;
#endif

class YouTubeUserPlaylistListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)

public:
    enum Roles {
        IdRole = Qt::UserRole + 1,
        PlaylistIdRole,
        TitleRole,
        ArtistRole,
        ArtistAvatarUrlRole,
        DateRole,
        VideoCountRole,
#ifndef QML_USER_INTERFACE
        ThumbnailRole,
#endif
        ThumbnailUrlRole,
        LargeThumbnailUrlRole,
        DescriptionRole
    };

public:
    explicit YouTubeUserPlaylistListModel(QObject *parent = 0);
    ~YouTubeUserPlaylistListModel();
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    QSharedPointer<PlaylistItem> get(int row) const;
#ifdef QML_USER_INTERFACE
    Q_INVOKABLE PlaylistItem* getFromQML(int row) const;
#endif

private slots:
    void onPlaylistAdded(int row);
    void onPlaylistRemoved(int row);
    void onPlaylistUpdated(int row);
#ifndef QML_USER_INTERFACE
    void onThumbnailReady();
#endif

signals:
    void countChanged(int count);

#ifndef QML_USER_INTERFACE
private:
    ThumbnailCache *m_cache;
#endif
};

#endif // YOUTUBEUSERPLAYLISTLISTMODEL_H
